@@ -3,7 +3,7 @@
 from PIL import Image, ImageChops,ImageFilter
 from . import openFile
 from .options import *
-from .gradient import userAdaptGrandient
+from .gradient import userAdaptGrandient, colorBg
 import os
 path = os.path.dirname(__file__).replace("utils","assets")
 
@@ -692,6 +692,76 @@ async def creatFiveBg(userImages,element = "Rock",adapt = False):
     return bg
 
 
+async def openBgElementSeven(element):
+    if element == "Fire":
+        return openFile.PYRO_SEVEN
+    elif element== "Grass":
+        return openFile.DENDRO_SEVEN
+    elif element == "Electric":
+        return openFile.ELECTRO_SEVEN
+    elif element == "Water":
+        return openFile.GYDRO_SEVEN
+    elif element == "Wind":
+        return openFile.ANEMO_SEVEN
+    elif element== "Rock":
+        return openFile.GEO_SEVEN
+    else:
+        return openFile.CRYO_SEVEN
+
+async def centerSeven(userImages):
+    x,y = userImages.size
+    if max(x, y) / min(x, y) < 1.1:
+        baseheight = 734
+        hpercent = (baseheight / float (y)) 
+        wsize = int ((float (x) * float (hpercent)))
+        userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+        return userImages, (108,-50)
+        # квадратное 
+        pass
+    elif x > y:
+        basewidth = 940 
+        wpercent = (basewidth / float(userImages.size[0]))
+        hsize = int((float(userImages.size[1]) * float(wpercent)))
+        if hsize > 1690:
+            baseheight = 734
+            hpercent = (baseheight / float (y)) 
+            wsize = int ((float (x) * float (hpercent)))
+            userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+            return userImages, (108,-50)
+        userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
+        return userImages, (0,0)
+    else:
+        basewidth = 734
+        wpercent = (basewidth / float(userImages.size[0]))
+        hsize = int((float(userImages.size[1]) * float(wpercent)))
+        userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
+        return userImages, (108,-50)
+
+
+async def creatSevenBg(userImages,element = "Rock",adapt = False):
+    if adapt:
+        img, px = await centerSeven(userImages)
+        color = await colorBg(img)
+        bgA = Image.new("RGBA",(940,1010) ,color)
+        bg = bgA.copy()
+        bgA.alpha_composite(img,px)
+        bg = Image.composite(bg, bgA, openFile.MASKA_ADAPT.convert("L"))
+
+        bg = ImageChops.soft_light(bg,openFile.overlay_SEVEN.convert("RGBA"))        
+    else:
+        bgA = await openBgElementSeven(element)
+        bgA = bgA.copy().convert("RGBA")
+        bg = bgA.copy()
+        bgA.alpha_composite(userImages,(-224,-97))
+        bg = Image.composite(bg, bgA, openFile.MASKA_SPLASH.convert("L"))
+    bg.alpha_composite(openFile.SHADOW_SEVEN,(0,0))
+    bg.alpha_composite(openFile.FRAME_SEVEN,(0,0))    
+    return bg
+
+        
+
+
+
 async def charterElement(element):
     if element == "Fire":
         return openFile.PYROTeampleFiveElement
